@@ -129,6 +129,10 @@ class Template(object):
     return Template(self.source.getSource(name), self.renderer,
                     extmap=self.extmap, fmtcmp=self.fmtcmp)
 
+  #----------------------------------------------------------------------------
+  def __getitem__(self, name):
+    return self.getTemplate(name)
+
   #----------------------------------------------------------------------------
   def render(self, format, params):
     if format == 'spec':
